package cmdTemplate

import (
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type Del struct {
    Name string
}

func (cmd *Del)GetName() string {
    return cmd.Name
}

func (cmd *Del)GetDesc() []string {
    return []string{
        "Deletes a template.",
        "Requires TPL_DESTROY or TPL_DESTROY_ANY user capability."}
}

func (cmd *Del)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: ",cmd.GetName()," ID")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("ID      ID of the template to delete.")
}

func (cmd *Del)Run(args []string) int {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    argc := len(args)
    if argc != 1 {
        cmd.PrintUsage()
        return 1
    }

    tplID := args[0]
    statusCode := 0

    resp, err := client.R().Delete(host+"/templates/"+tplID)
    if err != nil {
        u.PrintlnErr("Failed deleting template \""+tplID+"\": "+err.Error())
        statusCode = 1
    } else {
        if resp.IsSuccess() {
            u.Println("Deleted template \""+tplID+"\"")
        } else {
            u.PrintlnErr("Failed deleting template \""+tplID+"\": "+resp.Status()+": "+resp.String())
            statusCode = 1
        }
    }

    return statusCode
}
