package cmdTemplate

import (
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type ListSingle struct {
    Name string
}

func (cmd *ListSingle)GetName() string {
    return cmd.Name
}

func (cmd *ListSingle)GetDesc() []string {
    return []string{
        "Lists a single template.",
        "Requires TPL_LIST or TPL_LIST_ANY user capability."}
}

func (cmd *ListSingle)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: ",cmd.GetName(), " ID")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
}

func (cmd *ListSingle)Run(args []string) int {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    argc := len(args)
    if argc < 1 {
        cmd.PrintUsage()
        return 1
    }

    uuid := args[0]
    resp, err := client.R().Get(host+"/templates/"+uuid)
    if err != nil {
        u.PrintlnErr("Failed retrieving template \""+uuid+"\": "+err.Error())
        return 1
    } else {
        if resp.IsSuccess() {
            tpl, err := deserializeTemplate(resp)
            if err != nil {
                u.PrintlnErr("Failed retrieving server's response: "+err.Error())
                return 1
            }
            str, err := tpl.String()
            if err != nil {
                u.PrintlnErr("Failed decoding template "+tpl.ID.String()+" to string. Skipped.")
            } else {
                u.Println(str)
            }
        } else {
            u.PrintlnErr("Failed retrieving template \""+uuid+"\": "+resp.Status()+": "+resp.String())
            return 1
        }
    }

    return 0
}
